@@ -15,7 +15,7 @@ def processVideo(input_directory, output_directory, day, hour, start_min, end_mi
 def getHour(hour_directory, start_min = 0, end_min = 59):
     #print(hour_directory)
     os.chdir(hour_directory)
-    minutes = os.listdir(hour_directory).sort()
+    minutes = sorted(os.listdir(hour_directory))
     clips = []
     for minute in minutes[start_min:end_min]:
         if minute.endswith(".mp4"):
@@ -25,4 +25,10 @@ def getHour(hour_directory, start_min = 0, end_min = 59):
                 pass
     video = mp.concatenate_videoclips(clips, method='compose')
     gc.collect()
-    return video
\ No newline at end of file
+    return video
+
+
+#getHour(
+#    hour_directory = "/Volumes/WYZE/record/20220318/14/", 
+#    start_min = 0,
+#    end_min = 2)
\ No newline at end of file
